##  Default Mapping
The flow chart helps illustrate the relations between ServiceNow tables and data flow conditions when constraints are used within the configuration.
![3397](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748126c7a441014b36fea591d1b0eab_LowRes.png)
Default-supported configuration workflow
